// Datei: dreieck.c
//
// Erzeugt zwei Sgezhne per PWM.
// Alle 5s 61Hz, Pegel fast 4.8Vss.
// Dann schwimmend auf 2.5V mit 122Hz und 2.3Vss.
//
//	Filter Diagram:
//		
//	           4k7             4k7	
//	RB3  ___/\  /\  /\______/\  /\  /\________ Analog Output
//	          \/  \/    |     \/  \/     |  
//	                    |                |
//	                  ----- 15nF       ----- 15nF
//	                  -----            -----
//	                    |                |
//	                   GND              GND
//
//
// hk@holger-klabunde.de
// www.holger-klabunde.de
// 05.05.2002
// Compiler CC5X

#include <16F628.h>
#include <inline.h>

// Watchdog off, Power up Timer on, XT Oscillator, kein Code Protect
#pragma config |=0x3F61

#include "interupt.c"
#include "delay.c"

//*******************************************************
// Hauptprogramm
//*******************************************************
void main()
{
 unsigned char i;
 
 CMCON=0b00000111;  //Comparator inaktiv

 CLRWDT;
 //Takt des PIC 4MHz, ein Zyklus = 1us
 OPTION=0b11000001; //Pullups off,Prescaler auf TMR0, 1:4

 TRISB=0b00000000;  //0=Ausgang, 1=Eingang
 TRISA=0b00000;     //0=Ausgang, 1=Eingang
 PORTB=0b00000000;  //Port einmal schreiben
 PORTA=0b00000000;  //Port einmal schreiben

 CCPR1L=0x00;        
 CCP1CON=0b00001111; //PWM-Mode
 PR2=63;             //Frequenz PWM 15,6kHz
 
 //Interrupts erlauben
 GIE=1;
 PEIE=1;           //Peripheral Interrupts an
 TMR2IE=1;         //TMR2 to PR2 Match Interrupt an
 T2CON=0b00000100; //Prescaler 1:1, TMR2 on

 while(1) // Programm-Endlosschleife
  {
   offset=0;
   for(i=0; i<20; i++) Delay1ms(250);
   offset=128;
   for(i=0; i<20; i++) Delay1ms(250);
  } //while(1) Endlosschleife
  
}
